| Title: | Gene Orthologs for Model Organisms in a Tidy Data Format |
|---|---|
| Description: | Genomic analysis of model organisms frequently requires the use of databases based on human data or making comparisons to patient-derived resources. This requires harmonization of gene names into the same gene space. The 'babelgene' R package converts between human and non-human gene orthologs/homologs. The package integrates orthology assertion predictions sourced from multiple databases as compiled by the HGNC Comparison of Orthology Predictions (HCOP) (Wright et al. 2005 <doi:10.1007/s00335-005-0103-2>, Eyre et al. 2007 <doi:10.1093/bib/bbl030>, Seal et al. 2011 <doi:10.1093/nar/gkq892>). |
| Authors: | Igor Dolgalev [aut, cre] (ORCID: <https://orcid.org/0000-0003-4451-126X>) |
| Maintainer: | Igor Dolgalev <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 22.9 |
| Built: | 2026-05-15 09:31:01 UTC |
| Source: | https://github.com/igordot/babelgene |
Retrieve gene orthologs/homologs for a set of genes. Converts between human and non-human analogs.
orthologs(genes, species, human = TRUE, min_support = 3, top = TRUE)orthologs(genes, species, human = TRUE, min_support = 3, top = TRUE)
genes |
A vector of gene symbols or Entrez/Ensembl IDs. |
species |
Species name, such as |
human |
A logical scalar indicating if the input genes are human. If |
min_support |
Minimum number of supporting source databases. Gene pairs available in this package are supported by 2 to 12 databases (the maximum varies depending on the species). |
top |
For each gene, output only the match with the highest support level if there are multiple hits. |
A data frame of gene pairs (human and given species).
Wright MW, Eyre TA, Lush MJ, Povey S, Bruford EA. HCOP: the HGNC comparison of orthology predictions search tool. Mamm Genome. 2005 Nov;16(11):827-8. doi:10.1007/s00335-005-0103-2
Eyre TA, Wright MW, Lush MJ, Bruford EA. HCOP: a searchable database of human orthology predictions. Brief Bioinform. 2007 Jan;8(1):2-5. doi:10.1093/bib/bbl030
Seal RL, Gordon SM, Lush MJ, Wright MW, Bruford EA. genenames.org: the HGNC resources in 2011. Nucleic Acids Res. 2011 Jan;39:D514-9. doi:10.1093/nar/gkq892
orthologs(genes = "TP53", species = "mouse", human = TRUE) orthologs(genes = c("Ptprc", "Cd34"), species = "mouse", human = FALSE)orthologs(genes = "TP53", species = "mouse", human = TRUE) orthologs(genes = c("Ptprc", "Cd34"), species = "mouse", human = FALSE)
List the species with available human orthologs.
species(species = NULL)species(species = NULL)
species |
Species name, such as |
A data frame of the available species.
species() species("Mus musculus") species("mouse") species("rat")species() species("Mus musculus") species("mouse") species("rat")